#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Proxy models for augmenting our source data tables with methods useful for processing.
"""
from __future__ import unicode_literals
from opencivicdata.elections.models import (
    BallotMeasureContest,
    BallotMeasureContestIdentifier,
    BallotMeasureContestOption,
    BallotMeasureContestSource,
)
from calaccess_processed.proxies import OCDProxyModelMixin
from calaccess_processed.managers import BulkLoadSQLManager


class OCDBallotMeasureContestProxy(BallotMeasureContest, OCDProxyModelMixin):
    """
    A proxy on the OCD BallotMeasureContest model.
    """

    objects = BulkLoadSQLManager()

    copy_to_fields = (
        ("id",),
        ("name",),
        ("division_id",),
        ("election_id",),
        ("description",),
        ("requirement",),
        ("classification",),
        ("runoff_for_contest_id",),
        ("created_at",),
        ("updated_at",),
        ("extras",),
        ("locked_fields",),
    )

    class Meta:
        """
        Make this a proxy model.
        """

        app_label = "calaccess_processed_elections"
        proxy = True


class OCDBallotMeasureContestIdentifierProxy(
    BallotMeasureContestIdentifier, OCDProxyModelMixin
):
    """
    A proxy on the OCD BallotMeasureContestIdentifier model.
    """

    objects = BulkLoadSQLManager()

    class Meta:
        """
        Make this a proxy model.
        """

        app_label = "calaccess_processed_elections"
        proxy = True


class OCDBallotMeasureContestOptionProxy(
    BallotMeasureContestOption, OCDProxyModelMixin
):
    """
    A proxy on the OCD BallotMeasureContestOption model.
    """

    objects = BulkLoadSQLManager()

    class Meta:
        """
        Make this a proxy model.
        """

        app_label = "calaccess_processed_elections"
        proxy = True


class OCDBallotMeasureContestSourceProxy(
    BallotMeasureContestSource, OCDProxyModelMixin
):
    """
    A proxy on the OCD BallotMeasureContestSource model.
    """

    objects = BulkLoadSQLManager()

    class Meta:
        """
        Make this a proxy model.
        """

        app_label = "calaccess_processed_elections"
        proxy = True
